@@ -22,6 +22,7 @@ import json
 import sys
 import os
 import zipfile
+from requests import exceptions
 
 headers_default = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:68.0) Gecko/20100101 Firefox/68.0"}
 
@@ -97,6 +98,8 @@ def download(
         size_limit: int = None,
         range_start: int = None,
         range_end: int = None,
+        overwrite: bool = False,
+        verify: bool = True
 ):
     """
     实现文件下载功能，可指定url、文件名、后缀名、请求头、文件保存路径
@@ -109,6 +112,8 @@ def download(
     :param size_limit:尺寸限制
     :param range_start:开始位置
     :param range_end:结束位置
+    :param overwrite: 覆盖
+    :param verify: 验证证书
     :return:
     """
     if not headers:
@@ -136,7 +141,8 @@ def download(
         url=url,
         headers=headers_local,
         stream=True,
-        proxies=proxies
+        proxies=proxies,
+        verify=verify
     )
     total_length = response.headers.get('content-length')  # 文件大小
     content_type = response.headers.get('content-type')  # 文件类型
@@ -192,6 +198,23 @@ def download(
     time_start = time.time()  # 获取下载开始时间
     is_finish = False
 
+    if overwrite and os.path.exists(path_local):
+        delete(file=path_local)
+    elif not overwrite and os.path.exists(path_local):
+        # 这里将对已存在的文件名重新命名
+        rename_count = 1
+        while True:
+            download_file_name_rename = f'{download_file_name.split(".")[0]}({rename_count}).{download_file_name.split(".")[1]}'
+            path_local_rename = os.path.join(path, download_file_name_rename)
+            if os.path.exists(path_local_rename):
+                rename_count += 1
+                continue
+            else:
+                break
+        path_local = copy.deepcopy(path_local_rename)
+    else:
+        pass
+
     with open(path_local, "ab") as f:  # wb新建文件，a追加
         for chunk in response.iter_content(chunk_size=chunk_size):
             try:
@@ -259,28 +282,35 @@ def safe_download(
         proxies=None,
         size_limit=None,
         range_start=None,
-        range_end=None
+        range_end=None,
+        verify: bool = False
 ):
     while True:
-        download_response = download(
-            url=url,
-            filename=filename,
-            suffix_name=suffix_name,
-            headers=headers,
-            path=path,
-            proxies=proxies,
-            size_limit=size_limit,
-            range_start=range_start,
-            range_end=range_end
-        )
-        if download_response.get('is_finish') is True:
-            local_file_dir = download_response.get('file_dir')
-            return local_file_dir
-        else:
-            print(':( 下载中断')
-            range_start = download_response.get('temp_size')
+        try:
+            download_response = download(
+                url=url,
+                filename=filename,
+                suffix_name=suffix_name,
+                headers=headers,
+                path=path,
+                proxies=proxies,
+                size_limit=size_limit,
+                range_start=range_start,
+                range_end=range_end,
+                overwrite=False,
+                verify=verify
+            )
+            if download_response.get('is_finish') is True:
+                local_file_dir = download_response.get('file_dir')
+                return local_file_dir
+            else:
+                print(':( 下载中断')
+                range_start = download_response.get('temp_size')
+                time.sleep(1)
+                print('将继续下载（断点续传）...')
+        except:
+            print(':( 下载中断，将重新下载...')
             time.sleep(1)
-            print('将继续下载（断点续传）...')
 
 
 def read(
@@ -308,6 +338,9 @@ def read(
         # 如果没指定后缀名，就忽略
         pass
 
+    if not os.path.exists(file_dir):
+        return
+
     if read_lines:
         with open(file=file_dir, mode='r', encoding='utf-8') as f:
             content = f.readlines()
@@ -351,7 +384,7 @@ def save(
 
     if suffix:
         # 如果指定了后缀名，就加上后缀名
-        file_dir = f'{file}.{suffix}'
+        file_dir = f'{file_dir}.{suffix}'
     else:
         # 如果没指定后缀名，就忽略
         pass
@@ -657,3 +690,26 @@ def unzip(
         else:
             continue
     return unzip_names
+
+
+def get_stream(
+        url,
+        verify=True,
+        **kwargs
+):
+    """
+    以流式传输方式发起请求，适用于下载文件时，当文件过大，不会立即下载。
+    当把get函数的stream参数设置成True时，它不会立即开始下载，当你使用iter_content或iter_lines遍历内容或访问内容属性时才开始下载。需要注意一点：文件没有下载之前，它也需要保持连接。
+    iter_content：一块一块的遍历要下载的内容
+    iter_lines：一行一行的遍历要下载的内容
+    """
+    try:
+        response = requests.get(
+            url=url,
+            verify=verify,
+            stream=True,
+            **kwargs
+        )
+    except exceptions.ConnectionError:
+        raise exceptions.ConnectionError(f"Could not reach host. Are you offline?")
+    return response
