@@ -12,6 +12,22 @@ import pytz
 import time
 import copy
 import sys
+import re
+
+
+def get_datetime_from_str(
+        string: str
+):
+    """
+    从字符串中识别出时间
+    目前这个模块还不完备
+    """
+    findres = dict()
+    find_datetime = re.findall(pattern=r'(\d\d\d\d-[0-1]\d-[0-3]\d [0-2]\d:[0-5]\d:[0-5]\d)', string=string)
+    findres['datetime'] = find_datetime
+    find_time = re.findall(pattern=r'([0-2]\d:[0-5]\d:[0-5]\d)', string=string)
+    findres['time'] = find_time
+    return findres
 
 
 def get_utc_datetime(
@@ -96,13 +112,24 @@ def get_day(
     return day
 
 
-def get_hour():
+def get_hour(
+        target=None
+) -> int:
     """
     获取当前系统的当前时间：小时数（24小时制）
     :return: 14
     """
-    hour = datetime.datetime.now().hour
-    return hour
+    if not target:
+        return datetime.datetime.now().hour
+    else:
+        if isinstance(target, datetime.datetime):
+            return target.hour
+        elif isinstance(target, str):
+            get_res = get_datetime_from_str(string=target)
+            if get_res.get("time"):
+                return int(get_res.get("time")[0].split(':')[0])
+        else:
+            return -1
 
 
 def get_minute():
@@ -335,14 +362,15 @@ def get_datetime2date(
     """
     datetime->date
     """
-    if isinstance(datetime_str, str):
-        datetime_timestamp = get_datetime2timestamp(datetime_str)
+    temp = copy.deepcopy(datetime_str)  # 复制一份防止发生更改
+    if isinstance(temp, str):
+        datetime_timestamp = get_datetime2timestamp(temp)
         date_str = get_timestamp2date(datetime_timestamp)
         return date_str
-    elif isinstance(datetime_str, datetime.datetime):
-        return datetime_str.strftime(f)
+    elif isinstance(temp, datetime.datetime):
+        return temp.strftime(f)
     else:
-        return datetime_str
+        return temp
 
 
 def timestamp_day_num_start(
@@ -592,12 +620,28 @@ def datetime_string_chs(
 
 
 def date_str_list(
-        start_date: str,
-        end_date: str
+        start_date: str = None,
+        end_date: str = None,
+        start_days: int = None,
+        end_days: int = None
 ):
     # 生成起止时间之间的时间序列
-    start_date_f = get_format_date(start_date)
-    end_date_f = get_format_date(end_date)
+    current_day = datetime.date.today()
+
+    if start_date:
+        start_date_f = get_format_date(start_date)
+    elif start_days:
+        start_date_f = current_day + datetime.timedelta(days=start_days)
+    else:
+        start_date_f = current_day
+
+    if end_date:
+        end_date_f = get_format_date(end_date)
+    elif end_days:
+        end_date_f = current_day + datetime.timedelta(days=end_days)
+    else:
+        end_date_f = current_day
+    # print(start_date_f, '-->', end_date_f)
     date_list = list()
     date_list.append(str(start_date_f))
     added_date = start_date_f
